#ifndef ARRAYCORE_HEADERS
#define ARRAYCORE_HEADERS

// All headers of ArrayCore library

#include "AbstractArrayResults.h"
#include "AbstractArrayTool.h"
#include "AbstractEllipticityEngine.h"
#include "AbstractFKFunction.h"
#include "AbstractFKRayleigh.h"
#include "ActiveConvEllipticityEngine.h"
#include "ActiveConvFKRayleigh.h"
#include "ActiveConvFKRayleighAll.h"
#include "ActiveConvFKRayleighRadial.h"
#include "ActiveConvFKRayleighVertical.h"
#include "ActiveConvFKVertical.h"
#include "ActiveFKParameters.h"
#include "ActiveFKSteering.h"
#include "ActiveFKTask.h"
#include "ActiveFKTaskManager.h"
#include "ActiveFKTool.h"
#include "ActiveFKToolSet.h"
#include "ActiveFKWorker.h"
#include "ActiveHRFKRayleigh.h"
#include "ActiveHRFKVertical.h"
#include "ArrayCoreDLLExport.h"
#include "ArrayCrossSpectrum.h"
#include "ArrayParameters.h"
#include "ArraySelection.h"
#include "ArrayStationSignals.h"
#include "ArrayStations.h"
#include "ArrayTask.h"
#include "ArrayTaskManager.h"
#include "ArrayTimeWindows.h"
#include "ArrayWorker.h"
#include "AsyncArrayProcess.h"
#include "AsyncFKLoop.h"
#include "AsyncFKTool.h"
#include "AsyncParameters.h"
#include "AsyncStationPair.h"
#include "BlockAveragingParameters.h"
#include "ConvEllipticityEngine.h"
#include "ConvFKRadial.h"
#include "ConvFKRayleigh.h"
#include "ConvFKRayleighAll.h"
#include "ConvFKRayleighRadial.h"
#include "ConvFKRayleighVertical.h"
#include "ConvFKTransverse.h"
#include "ConvFKVertical.h"
#include "ConvThreeComponentXiFunction.h"
#include "CrossSpectrum.h"
#include "CrossSpectrumSplit.h"
#include "ESACStatistics.h"
#include "FKCache.h"
#include "FKCrossSpectrum.h"
#include "FKFunctionPlot.h"
#include "FKGradientSearch.h"
#include "FKParameters.h"
#include "FKPeaks.h"
#include "FKPolarGradientSearch.h"
#include "FKPower.h"
#include "FKResults.h"
#include "FKSteering.h"
#include "FKTaskManager.h"
#include "FKTool.h"
#include "FKWorker.h"
#include "HRDirectEllipticityEngine.h"
#include "HREllipticityEngine.h"
#include "HRFKAngularRayleighEllipticity.h"
#include "HRFKDirectLove.h"
#include "HRFKDirectRadial.h"
#include "HRFKDirectRayleigh.h"
#include "HRFKDirectRayleighAll.h"
#include "HRFKDirectRayleighRadial.h"
#include "HRFKDirectRayleighSquared.h"
#include "HRFKDirectRayleighVertical.h"
#include "HRFKDirectTransverse.h"
#include "HRFKRadial.h"
#include "HRFKRayleigh.h"
#include "HRFKRayleighAll.h"
#include "HRFKRayleighFixedEll.h"
#include "HRFKRayleighRadial.h"
#include "HRFKRayleighSquared.h"
#include "HRFKRayleighVertical.h"
#include "HRFKTransverse.h"
#include "HRFKVertical.h"
#include "IncoherentNoise.h"
#include "KNullSolver.h"
#include "KmaxSolver.h"
#include "KminSolver.h"
#include "MSPACStatistics.h"
#include "MuttiArrayFKLoop.h"
#include "ORACrossSpectrum.h"
#include "ORAParameters.h"
#include "ORATaskManager.h"
#include "ORATool.h"
#include "ORAWorker.h"
#include "OmniFKRayleigh.h"
#include "OmniFKVertical.h"
#include "PoggiFKRadial.h"
#include "PoggiFKVertical.h"
#include "RingPairs.h"
#include "SPACCrossSpectrum.h"
#include "SPACParameters.h"
#include "SPACPeaks.h"
#include "SPACResults.h"
#include "SPACRing.h"
#include "SPACTaskManager.h"
#include "SPACTool.h"
#include "SPACWorker.h"
#include "SensorOrientationCapon.h"
#include "SensorOrientationFunction.h"
#include "SensorOrientationTaskManager.h"
#include "SensorOrientationWorker.h"
#include "SimulatedArrayStations.h"
#include "SingleDirectRayleigh.h"
#include "StationPair.h"
#include "StationPairs.h"
#include "SteeringFactors.h"
#include "WaveNumberConverter.h"
#include "Wavefield.h"
#include "WavefieldFunction.h"
#include "WavefieldValues.h"
#include "Wavenumber.h"

#ifndef GP_EXPLICIT_LIBRARY_NAMESPACE
using namespace ArrayCore;
#endif

#endif // ARRAYCORE_HEADERS
